SystemOrganization addCategory: #ConfigurationOfOrcaDev!

Object subclass: #ConfigurationOfOrcaDev
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfOrcaDev'!

!ConfigurationOfOrcaDev class methodsFor: 'private' stamp: 'LT 4/15/2011 13:44:23.44'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfOrcaDev class methodsFor: 'private' stamp: 'LT 4/15/2011 13:44:13.814'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfOrcaDev class methodsFor: 'metacello tool support' stamp: 'LT 4/15/2011 13:44:01.143'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfOrcaDev class methodsFor: 'metacello tool support' stamp: 'LT 4/15/2011 13:43:55.27'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfOrcaDev class methodsFor: 'loading' stamp: 'LT 4/15/2011 13:43:50.439'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfOrcaDev class methodsFor: 'metacello tool support' stamp: 'LT 4/15/2011 13:43:45.134'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfOrcaDev class methodsFor: 'accessing' stamp: 'LT 4/15/2011 13:43:38.368'!
project

	^self new project! !

!ConfigurationOfOrcaDev class methodsFor: 'unloading Metacello' stamp: 'LT 4/15/2011 13:44:37.238'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfOrcaDev methodsFor: 'baselines' stamp: 'lw 12/11/2011 17:45'!
baseline100: spec
	<version: '1.0-baseline'>

	| orcaRepo |
	orcaRepo := 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/Orca'.
	spec for: #common do: [
		spec 
			blessing: #baseline;
			repository: orcaRepo;
			postLoadDoIt: #setupDevEnvironment.
			
		spec project: 'Orca' with: [
			spec
				className: 'ConfigurationOfOrca';
				repository: orcaRepo;
				postLoadDoIt: #loadDevOfOmniBrowser
		].
	
		spec project: 'ConfigurationOfOCompletion' with: [
			spec
				className: 'ConfigurationOfOCompletion';
				repository: 'http://www.squeaksource.com/MetacelloRepository';
				postLoadDoIt: #loadOcompletionForOB
		].
		
		spec package: 'OcompletionSqueakCompatibility' with: 
			[spec repository: 'http://www.squeaksource.com/OCompletion' ].
		
		spec package: 'ConfigurationOfShout' with:
			[spec repository: 'http://www.squeaksource.com/MetacelloRepository'].
	].! !

!ConfigurationOfOrcaDev methodsFor: 'setup' stamp: 'LT 4/15/2011 14:14:00.856'!
enableDebugging

	(Smalltalk at: #Utilities) debugSwazooErrors: true.
	(Smalltalk at: #OrcaTranslationUpdatesPrinter) printUpdatesOf: (Smalltalk at: #OrcaTranslatedClass).! !

!ConfigurationOfOrcaDev methodsFor: 'baselines' stamp: 'LT 4/15/2011 18:25:01.405'!
loadDevOfOmniBrowser
		
	"TODO: Write in metacello style. was not sure how to specify that Dev version is wanted"
	(Installer ss project: 'MetacelloRepository') install: 'ConfigurationOfOmniBrowser'.
	((Smalltalk at: #ConfigurationOfOmniBrowser) project version: '1.2') load: #(Dev).! !

!ConfigurationOfOrcaDev methodsFor: 'baselines' stamp: 'LT 4/15/2011 18:29:00.653'!
loadOcompletionForOB
	
		"TODO: Write in metacello style. was not sure how to specify that Dev version is wanted"
	(Installer ss project: 'OCompletion') install: 'OCForOB-rr.2'.! !

!ConfigurationOfOrcaDev methodsFor: 'accessing' stamp: 'LT 4/15/2011 14:15:29.999'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfOrcaDev methodsFor: 'setup' stamp: 'OrcaSetup 1/6/2012 22:04'!
setPreferences

	SystemBrowser default: (Smalltalk at: #OBSystemBrowserAdaptor).
	
	World color: Preferences defaultWorldColor.
	TextEditor autoEnclose: true.
	MCConfiguration extraProgressInfo: true.
	SystemWindow 
		hideExpandButton: true;
		reuseWindows: true.
	
	Preferences
		installUniformWindowColors;
		enable: #swapMouseButtons;
		enable: #roundedWindowCorners;
		enable: #infiniteUndo;
		enable: #multipleTextUndo;
		enable: #higherPerformance;
		enable: #annotationPanes;
		disable: #fastDragWindowForMorphic;
		disable: #mercuryPanel.	! !

!ConfigurationOfOrcaDev methodsFor: 'setup' stamp: 'LT 4/15/2011 14:42:02.803'!
setupDevEnvironment

	self 
		enableDebugging;
		setPreferences.! !

!ConfigurationOfOrcaDev methodsFor: 'versions' stamp: 'LT 4/15/2011 14:16:34.688'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >

	spec for: #common do: [
		spec blessing: #stable.
	].! !
